==> vtk6-6.3.0-11-armv6h.pkg.tar.xz: vtk/vtkTIFFReader.java <==
// java wrapper for vtkTIFFReader object
//

package vtk;
import vtk.*;

public class vtkTIFFReader extends vtkImageReader2
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int CanReadFile_2(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_2(id0); }

  private native String GetFileExtensions_3();
  public String GetFileExtensions()
    { return GetFileExtensions_3(); }

  private native String GetDescriptiveName_4();
  public String GetDescriptiveName()
    { return GetDescriptiveName_4(); }

  private native void SetOrientationType_5(int id0);
  public void SetOrientationType(int id0)
    { SetOrientationType_5(id0); }

  private native int GetOrientationType_6();
  public int GetOrientationType()
    { return GetOrientationType_6(); }

  private native boolean GetOrientationTypeSpecifiedFlag_7();
  public boolean GetOrientationTypeSpecifiedFlag()
    { return GetOrientationTypeSpecifiedFlag_7(); }

  private native void SetOriginSpecifiedFlag_8(boolean id0);
  public void SetOriginSpecifiedFlag(boolean id0)
    { SetOriginSpecifiedFlag_8(id0); }

  private native boolean GetOriginSpecifiedFlag_9();
  public boolean GetOriginSpecifiedFlag()
    { return GetOriginSpecifiedFlag_9(); }

  private native void OriginSpecifiedFlagOn_10();
  public void OriginSpecifiedFlagOn()
    { OriginSpecifiedFlagOn_10(); }

  private native void OriginSpecifiedFlagOff_11();
  public void OriginSpecifiedFlagOff()
    { OriginSpecifiedFlagOff_11(); }

  private native void SetSpacingSpecifiedFlag_12(boolean id0);
  public void SetSpacingSpecifiedFlag(boolean id0)
    { SetSpacingSpecifiedFlag_12(id0); }

  private native boolean GetSpacingSpecifiedFlag_13();
  public boolean GetSpacingSpecifiedFlag()
    { return GetSpacingSpecifiedFlag_13(); }

  private native void SpacingSpecifiedFlagOn_14();
  public void SpacingSpecifiedFlagOn()
    { SpacingSpecifiedFlagOn_14(); }

  private native void SpacingSpecifiedFlagOff_15();
  public void SpacingSpecifiedFlagOff()
    { SpacingSpecifiedFlagOff_15(); }

  public vtkTIFFReader() { super(); }

  public vtkTIFFReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-13-armv6h.pkg.tar.xz: vtk/vtkTIFFReader.java <==
// java wrapper for vtkTIFFReader object
//

package vtk;
import vtk.*;

public class vtkTIFFReader extends vtkImageReader2
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int CanReadFile_2(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_2(id0); }

  private native String GetFileExtensions_3();
  public String GetFileExtensions()
    { return GetFileExtensions_3(); }

  private native String GetDescriptiveName_4();
  public String GetDescriptiveName()
    { return GetDescriptiveName_4(); }

  private native void SetOrientationType_5(int id0);
  public void SetOrientationType(int id0)
    { SetOrientationType_5(id0); }

  private native int GetOrientationType_6();
  public int GetOrientationType()
    { return GetOrientationType_6(); }

  private native boolean GetOrientationTypeSpecifiedFlag_7();
  public boolean GetOrientationTypeSpecifiedFlag()
    { return GetOrientationTypeSpecifiedFlag_7(); }

  private native void SetOriginSpecifiedFlag_8(boolean id0);
  public void SetOriginSpecifiedFlag(boolean id0)
    { SetOriginSpecifiedFlag_8(id0); }

  private native boolean GetOriginSpecifiedFlag_9();
  public boolean GetOriginSpecifiedFlag()
    { return GetOriginSpecifiedFlag_9(); }

  private native void OriginSpecifiedFlagOn_10();
  public void OriginSpecifiedFlagOn()
    { OriginSpecifiedFlagOn_10(); }

  private native void OriginSpecifiedFlagOff_11();
  public void OriginSpecifiedFlagOff()
    { OriginSpecifiedFlagOff_11(); }

  private native void SetSpacingSpecifiedFlag_12(boolean id0);
  public void SetSpacingSpecifiedFlag(boolean id0)
    { SetSpacingSpecifiedFlag_12(id0); }

  private native boolean GetSpacingSpecifiedFlag_13();
  public boolean GetSpacingSpecifiedFlag()
    { return GetSpacingSpecifiedFlag_13(); }

  private native void SpacingSpecifiedFlagOn_14();
  public void SpacingSpecifiedFlagOn()
    { SpacingSpecifiedFlagOn_14(); }

  private native void SpacingSpecifiedFlagOff_15();
  public void SpacingSpecifiedFlagOff()
    { SpacingSpecifiedFlagOff_15(); }

  public vtkTIFFReader() { super(); }

  public vtkTIFFReader(long id) { super(id); }
  public native long   VTKInit();

}
